Pybman (*work in progress*)
=============================

Synopsis
--------

This is a python3 package (under development) for interacting with `MPG.PuRe <https://pure.mpg.de>`_ via the `PubMan REST API <https://pure.mpg.de/rest/swagger-ui.html>`_.
